@@ -37,8 +37,8 @@
 ##'          \item error_by_prod: the error by product (CATATIS criterion)
 ##'          \item s_with_compromise: the similarity coefficient of each subject with the compromise
 ##'          \item homogeneity: homogeneity of the subjects (in percentage)
-##'          \item CA: the results of correspondance analysis performed on the compromise dataset
-##'          \item eigenvalues: the eigenvalues associated to the correspondance analysis
+##'          \item CA: the results of correspondence analysis performed on the compromise dataset
+##'          \item eigenvalues: the eigenvalues associated to the correspondence analysis
 ##'          \item inertia: the percentage of total variance explained by each axis of the CA
 ##'          \item scalefactors: the scaling factors of each subject
 ##'          \item nb_1: the number of 1 in each block, i.e. the number of checked attributes by subject.
@@ -47,7 +47,7 @@
 ##'
 ##'
 ##'
-##' @keywords CATA RATA
+##' @keywords CATA
 ##'
 ##' @references
 ##' Llobell, F., Cariou, V., Vigneau, E., Labenne, A., & Qannari, E. M. (2019). A new approach for the analysis of data and the clustering of subjects in a CATA experiment. Food Quality and Preference, 72, 31-39.\cr
@@ -76,16 +76,6 @@
 ##' chang2=change_cata_format2(Data, nprod= 6, nattr= 27, nsub = 11, nsess= 1)
 ##' res.cat3=catatis(Data= chang2$Datafinal, nblo = 11, NameBlocks =  chang2$NameSub)
 ##'
-##' #RATA data with session
-##' data(RATAchoc)
-##' chang2=change_cata_format2(RATAchoc, nprod= 12, nattr= 13, nsub = 9, nsess= 3)
-##' res.cat4=catatis(Data= chang2$Datafinal, nblo = 9, NameBlocks =  chang2$NameSub)
-##'
-##' #RATA data without session
-##' Data=RATAchoc[1:108,2:16]
-##' chang2=change_cata_format2(Data, nprod= 12, nattr= 13, nsub = 9, nsess = 1)
-##' res.cat5=catatis(Data= chang2$Datafinal, nblo = 9, NameBlocks =  chang2$NameSub)
-##' graphics.off()
 ##'
 ##' @seealso   \code{\link{plot.catatis}}, \code{\link{summary.catatis}}, \code{\link{cluscata}}, \code{\link{change_cata_format}}, \code{\link{change_cata_format2}}
 ##'
@@ -278,6 +268,7 @@ catatis=function(Data,nblo,NameBlocks=NULL, NameVar=NULL, Graph=TRUE, Graph_weig
     dev.new()
     barplot(eigenvalues, col="blue", main="Eigenvalues")
     dev.new()
+    options(ggrepel.max.overlaps = Inf)
     print(plot.CA(e,title=paste("CATATIS")))
   }
 
